@@ -5,24 +5,23 @@
 # This code is part of the package:
 # Antarctic-plots (https://github.com/mdtanker/antarctic_plots)
 #
-import warnings
 
-import geopandas as gpd
 import numpy as np
 import pandas as pd
 import pygmt
+import pyogrio
 import verde as vd
 
-from antarctic_plots import fetch
+from antarctic_plots import fetch, utils
 
 
 def create_profile(
     method: str,
     start: np.ndarray = None,
     stop: np.ndarray = None,
-    shapefile: str = None,
     num=100,
     shp_num_points: int = None,
+    shapefile: str = None,
     **kwargs,
 ):
     """
@@ -61,7 +60,8 @@ def create_profile(
     elif method == "shapefile":
         if shapefile is None:
             raise ValueError(f"If method = {method}, need to provide a valid shapefile")
-        shp = gpd.read_file(shapefile)
+        # shp = gpd.read_file(shapefile)
+        shp = pyogrio.read_dataframe(shapefile)
         df = pd.DataFrame()
         df["coords"] = shp.geometry[0].coords[:]
         coordinates = df.coords.apply(pd.Series, index=["x", "y"])
@@ -125,9 +125,7 @@ def sample_grids(df, grid, name: str = None):
     return df
 
 
-def fill_nans(
-    df,
-):
+def fill_nans(df):
     """
     Fill NaN's in sampled layer with values from above layer.
 
@@ -207,16 +205,17 @@ def make_data_dict(names: list, grids: list, colors: list) -> dict:
 
 def default_layers() -> dict:
     """
-    Fetch default Bedmap2 layers.
+    Fetch default Bedmachine layers.
 
     Returns
     -------
     dict[dict]
-        Nested dictionary of Bedmap2 layers and attributes
+        Nested dictionary of Bedmachine layers and attributes
     """
-    surface = fetch.bedmap2("surface")
-    icebase = fetch.bedmap2("surface") - fetch.bedmap2("thickness")
-    bed = fetch.bedmap2("bed")
+    surface = fetch.bedmachine("surface")
+    # icebase = fetch.bedmachine("surface") - fetch.bedmachine("thickness")
+    icebase = fetch.bedmachine("icebase")
+    bed = fetch.bedmachine("bed")
     layer_names = [
         "surface",
         "icebase",
@@ -295,34 +294,40 @@ def plot_profile(
         `profile.make_data_dict`, by default is gravity and magnetic anomalies.
     add_map : bool = False
         Choose whether to add a location map, by default is False.
-    Other Parameters
-    ----------------
+
+    Keyword Args
+    ------------
     fillnans: bool
-        Choose whether to fill nans in layers, defaults to True
+        Choose whether to fill nans in layers, defaults to True.
     clip: bool
-        Choose whether to clip the profile based on distance
+        Choose whether to clip the profile based on distance.
     max_dist: int
         Clip all distances greater than.
     min_dist: int
         Clip all distances less than.
-    **kwargs : dict
-        map_background: str or xarray.DataArray
-            Change the map background by passing a filename string or grid, by default
-            is imagery.
-        map_cmap: str
-            Change the map colorscale by passing a valid GMT cmap string, by default is
-            'earth'.
-        map_buffer: float (0-1)
-            Change map zoom as relative percentage of profile length, by default is 0.2
-        layer_buffer: float (0-1)
-            Change vertical white space within cross-section, by default is 0.1
-        data_buffer: float (0-1)
-            Change vertical white space within data graph, by default is 0.1
-        save: bool
-            Choose to save the image, by default is False
-        path: str
-            Filename for saving image, by default is None.
+    map_background: str or xarray.DataArray
+        Change the map background by passing a filename string or grid, by default is
+        imagery.
+    map_cmap: str
+        Change the map colorscale by passing a valid GMT cmap string, by default is
+        'earth'.
+    map_buffer: float (0-1)
+        Change map zoom as relative percentage of profile length, by default is 0.3.
+    layer_buffer: float (0-1)
+        Change vertical white space within cross-section, by default is 0.1.
+    data_buffer: float (0-1)
+        Change vertical white space within data graph, by default is 0.1.
+    inset : bool
+        choose to plot inset map showing figure location, by default is True
+    inset_pos : str
+        position for inset map; either 'TL', 'TR', BL', 'BR', by default is 'TL'
+    save: bool
+        Choose to save the image, by default is False.
+    path: str
+        Filename for saving image, by default is None.
     """
+    inset = kwargs.get("inset", True)
+    inset_pos = kwargs.get("inset_pos", "TL")
 
     points = create_profile(method, **kwargs)
 
@@ -361,19 +366,13 @@ def plot_profile(
 
     if add_map is True:
         # Automatic data extent + buffer as % of line length
-        buffer = df_layers.dist.max() * kwargs.get("map_buffer", 0.2)
-        e = df_layers.x.min() - buffer
-        w = df_layers.x.max() + buffer
-        n = df_layers.y.min() - buffer
-        s = df_layers.y.max() + buffer
-
+        df_reg = vd.get_region((df_layers.x, df_layers.y))
+        buffer = df_layers.dist.max() * kwargs.get("map_buffer", 0.3)
+        fig_reg = utils.alter_region(df_reg, buffer=buffer)[1]
         # Set figure parameters
-        fig_height = 90  # in mm
-        fig_width = fig_height * (w - e) / (s - n)
-        fig_ratio = (s - n) / (fig_height / 1000)
-        fig_reg = [e, w, n, s]
-        fig_proj = "x1:" + str(fig_ratio)
-        fig_proj_ll = "s0/-90/-71/1:" + str(fig_ratio)
+        fig_proj, fig_proj_ll, fig_width, fig_height = utils.set_proj(
+            fig_reg, fig_height=9
+        )
 
         fig.coast(
             region=fig_reg,
@@ -449,8 +448,46 @@ def plot_profile(
             justify="CM",
             clearance="+tO",
         )
+
+        # add inset map
+        if inset is True:
+            inset_reg = [-2800e3, 2800e3, -2800e3, 2800e3]
+            inset_map = f"X{fig_width*.25}c"
+
+            with fig.inset(
+                position=f"J{inset_pos}+j{inset_pos}+w{fig_width*.25}c",
+                verbose="q",
+            ):
+                # gdf = gpd.read_file(fetch.groundingline())
+                gdf = pyogrio.read_dataframe(fetch.groundingline())
+                fig.plot(
+                    projection=inset_map,
+                    region=inset_reg,
+                    data=gdf[gdf.Id_text == "Ice shelf"],
+                    color="skyblue",
+                )
+                fig.plot(data=gdf[gdf.Id_text == "Grounded ice or land"], color="grey")
+                fig.plot(data=fetch.groundingline(), pen="0.2p,black")
+
+                fig.plot(
+                    x=[
+                        fig_reg[0],
+                        fig_reg[0],
+                        fig_reg[1],
+                        fig_reg[1],
+                        fig_reg[0],
+                    ],
+                    y=[
+                        fig_reg[2],
+                        fig_reg[3],
+                        fig_reg[3],
+                        fig_reg[2],
+                        fig_reg[2],
+                    ],
+                    pen="1p,black",
+                )
         # shift figure to the right to make space for x-section and profiles
-        fig.shift_origin(xshift=(fig_width / 10) + 1)
+        fig.shift_origin(xshift=(fig_width) + 1)
 
     # PLOT CROSS SECTION AND PROFILES
     # add space above and below top and bottom of cross-section
@@ -458,7 +495,7 @@ def plot_profile(
     max = df_layers[df_layers.columns[3:]].max().max()
     y_buffer = (max - min) * kwargs.get("layer_buffer", 0.1)
     # set region for x-section
-    region_layers = [
+    fig_reg = [
         df_layers.dist.min(),
         df_layers.dist.max(),
         min - y_buffer,
@@ -490,14 +527,14 @@ def plot_profile(
                 )
             fig.legend(position="JBR+jBL+o0c", box=True)
             fig.shift_origin(yshift="h+.5c")
-            fig.basemap(region=region_layers, projection="X9c/6c", frame=True)
-        except:
+            fig.basemap(region=fig_reg, projection="X9c/6c", frame=True)
+        except Exception:
             print("error plotting data profiles")
     else:
-        fig.basemap(region=region_layers, projection="X9c/9c", frame=True)
+        fig.basemap(region=fig_reg, projection="X9c/9c", frame=True)
 
     # plot colored df_layers
-    for k, v in layers_dict.items():
+    for i, (k, v) in enumerate(layers_dict.items()):
         fig.plot(
             x=df_layers.dist,
             y=df_layers[k],
@@ -505,6 +542,29 @@ def plot_profile(
             color=v["color"],
             frame=["nSew", "a"],
         )
+        # if i == len(layers_dict)-1:
+        #     fig.plot(
+        #         x=df_layers.dist,
+        #         y=df_layers[k],
+        #         close="+yb",
+        #         color=v["color"],
+        #         frame=["nSew", "a"],
+        #     )
+        #     fig.plot(
+        #         x=df_layers.dist,
+        #         y=df_layers[k],
+        #         close="+yb",
+        #         color=v["color"],
+        #         frame=["nSew", "a"],
+        #     )
+        # else:
+        #     fig.plot(
+        #         x=df_layers.dist,
+        #         y=df_layers[k],
+        #         close="+yb",
+        #         color=v["color"],
+        #         frame=["nSew", "a"],
+        #     )
 
     # plot lines between df_layers
     for k, v in layers_dict.items():
@@ -512,8 +572,8 @@ def plot_profile(
 
     # plot 'A','B' locations
     fig.text(
-        x=region_layers[0],
-        y=region_layers[3],
+        x=fig_reg[0],
+        y=fig_reg[3],
         text="A",
         font="20p,Helvetica,black",
         justify="CM",
@@ -521,8 +581,8 @@ def plot_profile(
         no_clip=True,
     )
     fig.text(
-        x=region_layers[1],
-        y=region_layers[3],
+        x=fig_reg[1],
+        y=fig_reg[3],
         text="B",
         font="20p,Helvetica,black",
         justify="CM",
